==> commons-utils-2.1.0-sources.jar: org/seppiko/commons/utils/http/HttpHeaders.java <==
/*
 * Copyright 2022 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.seppiko.commons.utils.http;

import java.util.ArrayList;
import java.util.ConcurrentModificationException;
import java.util.LinkedHashMap;
import java.util.List;

/**
 * Simple Http Headers implement for {@link java.net.http.HttpRequest}
 *
 * @author Leonard Woo
 */
public class HttpHeaders {

  /**
   * Empty http headers
   */
  public static final HttpHeaders NO_HEADERS = new HttpHeaders();

  private LinkedHashMap<String, ArrayList<String>> headers;
  private final String[] EMPTY_STRING_ARRAY = new String[]{};

  /**
   * HttpHeaders
   */
  private HttpHeaders() {
    headers = new LinkedHashMap<>();
  }

  /**
   * Create HttpHeader object
   *
   * @param name header name
   * @param values header values
   * @return HttpHeaders object
   */
  public static HttpHeaders setHeader(String name, String... values) {
    HttpHeaders headers = new HttpHeaders();
    headers.addHeader(name, values);
    return headers;
  }

  /**
   * Set header
   *
   * @param name header name
   * @param values header values
   */
  public void setHeaders(String name, String... values) {
    headers.put(name, new ArrayList<>(List.of(values)));
  }

  /**
   * Set a map to HttpHeader
   * @param headers Map-List
   */
  public void setHeaders(LinkedHashMap<String, ArrayList<String>> headers) {
    this.headers = headers;
  }

  /**
   * Add headers
   *
   * @param name header name
   * @param values header values
   * @throws IllegalArgumentException copy old values failed
   */
  public void addHeader(String name, String... values) throws IllegalArgumentException {
    if (headers.containsKey(name)) {
      ArrayList<String> valueOld = headers.get(name);
      ArrayList<String> valueNew = (ArrayList<String>) List.of(values);
      for (String s : valueOld) {
        if (!valueNew.contains(s)) {
          try {
            valueNew.add(s);
          } catch (UnsupportedOperationException | ClassCastException | IllegalArgumentException |
              NullPointerException ex) {
            throw new IllegalArgumentException(ex);
          }
        }
      }
      headers.put(name, valueNew);
    } else {
      setHeaders(name, values);
    }
  }

  /**
   * Get {@link java.net.http.HttpRequest} headers
   *
   * @return Headers
   * @throws IllegalCallerException Object init args exception
   * @throws IllegalArgumentException Args exception
   */
  public String[] getHeaderList() throws IllegalCallerException, IllegalArgumentException {
    return (headers.isEmpty())? EMPTY_STRING_ARRAY: headerHeadler(headers);
  }

  private String[] headerHeadler(LinkedHashMap<String, ArrayList<String>> headerMap)
      throws IllegalCallerException, IllegalArgumentException {
    ArrayList<String> headerList = new ArrayList<>();
    try {
      headerMap.forEach((key, value) -> {
        headerList.add(key);
        headerList.add(valuesHeadler(value));
      });

      return headerList.toArray(String[]::new);
    } catch (ConcurrentModificationException | ClassCastException | ArrayStoreException ex) {
      throw new IllegalCallerException(ex);
    } catch (UnsupportedOperationException | IllegalArgumentException ex){
      throw new IllegalArgumentException(ex);
    } catch (NullPointerException ignored) {
    }
    return EMPTY_STRING_ARRAY;
  }

  private static final char HTTP_HEADER_VALUE_SEPARTOR = ';';
  private String valuesHeadler(ArrayList<String> valueList) {
    StringBuilder sb = new StringBuilder();
    valueList.forEach(e -> {
      sb.append(e);
      sb.append(HTTP_HEADER_VALUE_SEPARTOR);
      sb.append(" ");
    });

    return sb.deleteCharAt( sb.lastIndexOf(HTTP_HEADER_VALUE_SEPARTOR + "") )
        .toString()
        .stripTrailing();
  }
}

==> commons-utils-2.6.0-sources.jar: org/seppiko/commons/utils/http/HttpHeaders.java <==
/*
 * Copyright 2022 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.seppiko.commons.utils.http;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.ConcurrentModificationException;
import java.util.LinkedHashMap;
import org.seppiko.commons.utils.StringUtil;

/**
 * Simple Http Headers implement for {@link java.net.http.HttpRequest}
 *
 * @author Leonard Woo
 */
public class HttpHeaders {

  private final LinkedHashMap<String, ArrayList<String>> headers = new LinkedHashMap<>();
  private final String[] EMPTY_STRING_ARRAY = new String[0];

  /**
   * HttpHeaders
   */
  private HttpHeaders() {
  }

  /**
   * create http headers
   *
   * @return new HttpHeaders object
   */
  public static HttpHeaders newHeaders() {
    return new HttpHeaders();
  }

  /**
   * Set header
   *
   * @param name header name
   * @param values header values
   * @return this
   */
  public HttpHeaders setHeaders(String name, String... values) {
    headers.put(name, new ArrayList<>(Arrays.asList(values)));
    return this;
  }

  /**
   * set cookie header
   *
   * @param cookies Http cookies
   * @return this
   */
  public HttpHeaders setCookie(HttpCookie... cookies) {
    ArrayList<String> cookieString = new ArrayList<>();
    Arrays.asList(cookies).forEach(cookie -> cookieString.add(cookie.toString()));
    setHeaders("Cookie", cookieString.toArray(String[]::new));
    return this;
  }

  /**
   * Add headers
   *
   * @param name header name
   * @param values header values
   * @return this
   * @throws IllegalArgumentException copy old values failed
   */
  public HttpHeaders addHeaders(String name, String... values) throws IllegalArgumentException {
    if (headers.containsKey(name)) {
      ArrayList<String> valueOld = headers.get(name);
      ArrayList<String> valueNew = new ArrayList<>(Arrays.asList(values));
      for (String value : valueOld) {
        if (!valueNew.contains(value)) {
          try {
            valueNew.add(value);
          } catch (UnsupportedOperationException | ClassCastException | IllegalArgumentException |
              NullPointerException ex) {
            throw new IllegalArgumentException(ex);
          }
        }
      }
      headers.put(name, valueNew);
    } else {
      setHeaders(name, values);
    }
    return this;
  }

  /**
   * Get {@link java.net.http.HttpRequest} headers
   *
   * @return Headers
   * @throws IllegalCallerException Object init args exception
   * @throws IllegalArgumentException Args exception
   */
  public String[] getHeaderList() throws IllegalCallerException, IllegalArgumentException {
    return (headers.isEmpty())? EMPTY_STRING_ARRAY: headerHeadler(headers);
  }

  private String[] headerHeadler(LinkedHashMap<String, ArrayList<String>> headerMap)
      throws IllegalCallerException, IllegalArgumentException {
    ArrayList<String> headerList = new ArrayList<>();
    try {
      headerMap.forEach((key, value) -> {
        headerList.add(key);
        headerList.add(valuesHeadler(value));
      });

      return headerList.toArray(String[]::new);
    } catch (ConcurrentModificationException | ClassCastException | ArrayStoreException ex) {
      throw new IllegalCallerException(ex);
    } catch (UnsupportedOperationException | IllegalArgumentException ex){
      throw new IllegalArgumentException(ex);
    } catch (NullPointerException ignored) {
    }
    return EMPTY_STRING_ARRAY;
  }

  private static final char HTTP_HEADER_VALUE_SEPARTOR = ';';
  private String valuesHeadler(ArrayList<String> valueList) {
    return StringUtil.convertJoinerString(HTTP_HEADER_VALUE_SEPARTOR + " ",
        valueList.toArray(String[]::new) );
  }
}
